@@ -301,11 +301,7 @@ class Application extends ApplicationConfig
                           .'/templates';
         $this->TPL = new Smarty;
         $this->TPL->error_reporting = false;
-        if ($this->DEBUG < 5) {
-            error_reporting(E_ALL ^ E_WARNING ^ E_NOTICE);
-        }
-
-        $this->TPL->compile_check = true;
+        $this->TPL->compile_check   = true;
 
         if (isset($this->config['DBTYPE'])) {
             $this->DB = new DBAccess($this->config['DBTYPE'],$this->config['DBUSER'],
@@ -394,10 +390,11 @@ class Application extends ApplicationConfig
         else {
             $parameter = $default;
         }
-        if (preg_match('/^(true|on|yes)$/i',$parameter)) {
+
+        if (preg_match('/^(true|on|yes)$/i',$parameter ?? '')) {
             $parameter = true;
         }
-        if (preg_match('/^(false|off|no)$/i',$parameter)) {
+        if (preg_match('/^(false|off|no)$/i',$parameter ?? '')) {
             $parameter = false;
         }
 
@@ -554,7 +551,7 @@ class Application extends ApplicationConfig
         }
 
         $debug_vals   = preg_split('/,(\s+)?/',$this->DEBUG);
-        $debug_global = array_shift($debug_vals) || 0;
+        $debug_global = array_shift($debug_vals) or 0;
         foreach ($debug_vals as $debug_entry) {
             list($debug_module,$level) = explode(':',$debug_entry);
             if (($debug_module == $module) && ($level >= $threshold)) {
@@ -663,7 +660,7 @@ class Application extends ApplicationConfig
                 return $this->_check_array($value,$UNICODE);
             }
             else {
-                return htmlentities(stripslashes($value),ENT_QUOTES);
+                return htmlentities(stripslashes($this->_request[$attr] ?? ''),ENT_QUOTES);
             }
         }
     }
@@ -729,12 +726,12 @@ class Application extends ApplicationConfig
         }
 
         // show sessionid in url
+        $sidprefix = '';
         if ($this->getConfig('URL_SESSIONID') == 'ENABLED') {
             $sidprefix = session_name().'='.session_id().'&';
         }
         $params .= $sidprefix;
 
-
         if (is_array($plist)) {
             foreach ($plist as $var => $value) {
                 $params .= '&'.$var.'='.$value;
