@@ -80,6 +80,14 @@ class DBAccess
     var $db;
 
 
+    /**
+     * Transaction flag
+     *
+     * @access private
+     */
+    var $db_transaction;
+
+
     /**
      * Statement handle
      *
