@@ -46,6 +46,11 @@ if ($searchMaskState = $App->getParam('searchMaskState')) {
     }
 
 }
+
+// Save storedSearch list
+if ($storedSearchState = $App->getParam('storedSearchState')) {
+    $App->setSession('storedSearchState',$storedSearchState);
+}
 eor();
 
 ?>
