@@ -53,7 +53,7 @@ catch (Exception $e) {
     $App->log($errorMsg);
 
     $aError = new aError($App->getMsg($errorMsg));
-    $App->view = a_errorResponse;
+    $App->view = 'a_errorResponse';
 }
 
 ?>
