@@ -35,7 +35,7 @@
 $MSG = $App->getParam('MSG');
 
 $auth_error = false;
-if (preg_match('/^ERR/',$MSG)) {
+if (preg_match('/^ERR|ID_NOT_FOUND/',$MSG)) {
     $auth_error = true;
 }
 
