@@ -32,7 +32,7 @@
  */
 
 // EMail from session (s.a. pre_ctrl)
-$filename    = $App->getParam('name');
+$filename    = $App->getParam('name',true);
 $attachmentId = $App->getParam('attachmentId');
 $contentType = $App->getParam('type');
 $sessionMailId = $App->getParam('id');
