@@ -182,7 +182,7 @@ $App->setSession('FilterList',$FilterList);
 $App->setSession('clientTimezone',$clientTimezone);
 
 // set language on change and after login for 32 days
-setcookie("BENNO_LANGUAGE", $LANG, time()+2764800, dirname($_SERVER['REQUEST_URI']));
+setcookie("BENNO_LANGUAGE", $LANG ?? '', time()+2764800, dirname($_SERVER['REQUEST_URI']));
 
 if ($redirect = $App->getSession('LOGIN_REDIRECT')) {
     // redirect to permalink
