@@ -31,7 +31,7 @@
  * Suite 330, Boston, MA  02111-1307  USA
  */
 require_once 'ctrl/CsrfToken.php';
-$data = $App->getParam('data');
+$data = $App->getParam('data',true);
 
 if(!CsrfToken::validate($App->getParam('csrf_token'))){
     $redata['MSG'] = 'INVALID_CSRF_TOKEN';
