@@ -30,7 +30,7 @@
  * If not, write to the Free Software Foundation, Inc., 59 Temple Place,
  * Suite 330, Boston, MA  02111-1307  USA
  */
-$searchstring = $App->getParam('searchmin');
+$searchstring = $App->getParam('searchmin',true);
 
 $queryId = sha1($searchstring);
 try {
