@@ -31,15 +31,12 @@
  * Suite 330, Boston, MA  02111-1307  USA
  */
 
-include_once 'model/Backend.php';
-
 $QueryResult = $App->getSession('QueryResult');
-$Backend     = $App->getSession('Backend');
 
 $sessionMailId = $App->getParam('id');
 
 try {
-    $EMail = $Backend->fetch($sessionMailId);
+    $EMail = $Backend->fetch($archive,$sessionMailId);
 }
 catch (Exception $e) {
     $App->log('[searchSimple] '.$e->getMessage());
