@@ -32,7 +32,7 @@
  */
 
 require_once 'model/StoredQuery.php';
-$extForm   = $App->getParam('ext');
+$extForm   = $App->getParam('ext',true);
 $queryName = $App->getParam('queryName');
 $queryName = urldecode($queryName);         // "..." will be url-encoded
 
