@@ -43,6 +43,7 @@ class Backend implements Serializable
     var $filter;        // filter assign to each query
     var $rest_user;
     var $rest_pass;
+    var $rest_ssl_verify;
     var $_curl;
 
     function __construct($base_url,$rest_user,$rest_pass,$filter)
@@ -300,7 +301,7 @@ class Backend implements Serializable
                 }
             }
             else {
-                throw new Exception('ERR_REQUEST');
+                throw $e;
             }
         }
 
@@ -375,7 +376,7 @@ class Backend implements Serializable
         }
 
         // set proxy for cURL requests (null or value from config / environment)
-        $rest_proxy = strtolower($App->getConfig('REST_PROXY',null));
+        $rest_proxy = strtolower($App->getConfig('REST_PROXY',''));
         if ($rest_proxy != 'environment') {
             curl_setopt($curl, CURLOPT_PROXY, $rest_proxy);
         }
@@ -392,20 +393,32 @@ class Backend implements Serializable
             }
         }
         $httpCode = curl_getinfo($curl, CURLINFO_HTTP_CODE); 
+        list($response_headers, $response_body) = explode("\r\n\r\n", $response, 2);
+
         switch ($httpCode) {
             case 200:
                 break;
             case 401:
                 $App->log('[Backend/query] HTTP STATUS '.$httpCode.', REST backed password incorrect.');
                 throw new Exception('ERR_REST_'.$httpCode);
+            case 404:
+                $jbody = json_decode($response_body,true);
+                if ($jbody['error'] == "container not initialized") {
+                    $App->log("[Backend/query] HTTP STATUS $httpCode, Container '".$jbody['container']."' not found");
+                    throw new Exception('ERR_INITIALIZE');
+                }
+                elseif ($jbody['error'] == "container not found") {
+                    $App->log("[Backend/query] HTTP STATUS $httpCode, Container not found");
+                    throw new Exception('ERR_ARCHIVE');
+                }
+                else {
+                    throw new Exception('ERR_REST_404');
+                }
             default:
                 $App->log('[Backend/query] HTTP ERROR '.$httpCode.', query: "'.$query.'"');
                 throw new Exception('ERR_REST_'.$httpCode);
         }
 
-        // split header / body
-        list($response_headers, $response_body) = explode("\r\n\r\n", $response, 2);
-
         if (!$response_body) {
             // empty body (logout,...) 
             $App->log('Empty response from backend',4,'Backend');
