@@ -37,6 +37,7 @@ class MailObject
 
     var $id;        // searchId
     var $permaId;   // id to access email: base64(<box>:<bennoId>@<archive>)
+    var $bennoId;
     var $from;
     var $to;
     var $cc;
@@ -47,9 +48,11 @@ class MailObject
     var $time;
     var $size;
     var $body;
+    var $attachments;
     var $bodytype;
     var $isError;
     var $errorMsg;
+    var $verified;
 
 
     function __construct($id,$permaId,$bennoId='',$from='',$to='',$cc='',$bcc='',$subject='',$date='',$time='',$size='',$body='',$attachments=array())
