@@ -200,9 +200,21 @@ class Query
     }
 
 
+    /**
+     * returns base64 encoded attribute value
+     *
+     * @return string
+     *
+     */
+    function getB64($attribute)
+    {
+        return base64_encode($this->$attribute);
+    }
+
+ 
 
     /**
-     * returns string for the simple search form
+     * returns base64 encoded string for the simple search form
      *
      * @return string
      *
@@ -215,7 +227,7 @@ class Query
         if (! $this->headerName) {            // every other param could be ''
             $field_text = $this->text;
         }
-        return $field_text;
+        return base64_encode($field_text);
     }
 
  
@@ -356,7 +368,8 @@ class Query
         }
 
         if ($this->subject !== '') {
-            $subject_string = $this->_format_query($this->subject,'Subject');
+            $attribute = str_replace('%','%25',$this->subject);
+            $subject_string = $this->_format_query($attribute,'Subject');
             $query_string .= '('.$subject_string.')';
             $query_string .= $and;
         }
@@ -368,7 +381,8 @@ class Query
         }
 
         if ($this->text !== '')   {
-            $text_string = $this->_format_query($this->text,'Text');
+            $attribute = str_replace('%','%25',$this->text);
+            $text_string = $this->_format_query($attribute,'Text');
             $query_string .= '('.$text_string.')';
             $query_string .= $and;
         }
