@@ -190,9 +190,12 @@ class UserDA extends Persistence
             1 => array('pipe', 'w'),
             2 => array('pipe', 'w')
         );
+        $cwd = null;
+        $env_vars['DEBUG']       = $App->getConfig('AUTH_DEBUG');
+        $env_vars['REMOTE_ADDR'] = $_SERVER['REMOTE_ADDR'];
 
         $cmd = escapeshellcmd($script);
-        $process = proc_open($cmd, $fd, $pipes);
+        $process = proc_open($cmd, $fd, $pipes, $cwd, $env_vars);
         $App->log('Call "'.$script.'" to authenticate.',2);
 
         $auth_sep = ' ';
