@@ -7,7 +7,7 @@ $App->assign('USERPANEL',$App->getSession('USERPANEL'));
 // theming
 $App->assign('THEME_PATH',$App->getConfig('THEME_PATH'));
 $App->assign('THEME_LOGO',$App->getConfig('THEME_LOGO'));
-$App->assign('THEME_LOGO_LINK',$App->getConfig('THEME_LOGO_LINK'));
+$App->assign('THEME_LOGO_LINK',$App->getConfig('THEME_LOGO_LINK','?CA=showCurrent'));
 
 // allowed forward recipients
 $App->assign('MAILTO_REGEX',$App->getConfig('MAILTO_REGEX','^(([^<>()\[\]\\\\.,;:\s@"]+(\.[^<>()\[\]\\\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$'));
