@@ -64,8 +64,17 @@ foreach ($EMail->getAttachments() as $Attachment) {
 
     $openWindow = false;
     $show_inline = $App->getConfigList('ATTACHMENT_INLINE',array('application/pdf','image/png'));
-    if (in_array($Attachment->type,$show_inline)) {
-        $openWindow = true;        // open attachment inline
+    if (in_array($Attachment->type,$show_inline)) {     // --> ctrl/downloadAttachment
+        $openWindow = true;
+    }
+    else { // show inline if file suffix matches
+        $itype_list = $App->getConfiglist('ATTACHMENT_INLINE_SUFFIX',array('application/pdf','image/png'));
+        foreach ($itype_list as $itype) {
+        list($type,$isuffix) = explode('/',$itype);
+            if (preg_match("/\.$isuffix$/i", $Attachment->id)) {
+                $openWindow = true;
+            }
+        }
     }
 
     $atm['id']           = urlencode($Attachment->id);
