@@ -53,7 +53,7 @@ catch (Exception $e) {
 
 $App->assign('Benno',$Benno);
 $App->assign('FilterList',$FilterList);
-$App->assign('DISABLED',$App->getConfigList('INFO_DISABLED'));
+$App->assign('INFOTEXT_TPL',$App->getConfig('INFOTEXT_TPL','infotext.tpl'));
 
 // no header / footer of template needed
 $App->assign('EMPTY',true);
