@@ -75,7 +75,7 @@ if (isset($show_greeting)) {
 }
 
 // load mail in content area
-if ($sessionMailId  || $show_greeting) {
+if ($sessionMailId  || @$show_greeting) {
     $App->assign('showMailContent','TRUE');
     $App->assign('currentMailId',$sessionMailId);
     $App->assign('hideFirstResult',$App->getConfig('HIDE_FIRST_RESULT',0));
