@@ -26,7 +26,7 @@ sub new
 
     $self->_init($configfile);
 
-    return $config;
+    return $self;
 }
 
 
